Fix some signedness issues caught by gcc 4.3


git-svn-id: svn://svn.savannah.nongnu.org/qemu/trunk@4696 c046a42c-6fe2-441c-8c8c-71466251a162
diff --git a/hw/gus.c b/hw/gus.c
index 57753a7..c7a8846 100644
--- a/hw/gus.c
+++ b/hw/gus.c
@@ -58,7 +58,7 @@
     QEMUSoundCard card;
     int freq;
     int pos, left, shift, irqs;
-    uint16_t *mixbuf;
+    GUSsample *mixbuf;
     uint8_t himem[1024 * 1024 + 32 + 4096];
     int samples;
     SWVoiceOut *voice;
@@ -198,7 +198,7 @@
 int GUS_read_DMA (void *opaque, int nchan, int dma_pos, int dma_len)
 {
     GUSState *s = opaque;
-    int8_t tmpbuf[4096];
+    char tmpbuf[4096];
     int pos = dma_pos, mode, left = dma_len - dma_pos;
 
     ldebug ("read DMA %#x %d\n", dma_pos, dma_len);
diff --git a/hw/gusemu.h b/hw/gusemu.h
index 2e9c1c0..a64300a 100644
--- a/hw/gusemu.h
+++ b/hw/gusemu.h
@@ -32,12 +32,14 @@
  typedef unsigned short GUSword;
  typedef unsigned int GUSdword;
  typedef signed char GUSchar;
+ typedef signed short GUSsample;
 #else
  #include <stdint.h>
  typedef int8_t GUSchar;
  typedef uint8_t GUSbyte;
  typedef uint16_t GUSword;
  typedef uint32_t GUSdword;
+ typedef int16_t GUSsample;
 #endif
 
 typedef struct _GUSEmuState
@@ -91,7 +93,7 @@
 /* If the interrupts are asynchronous, it may be needed to use a separate thread mixing into a temporary */
 /* audio buffer in order to avoid quality loss caused by large numsamples and elapsed_time values. */
 
-void gus_mixvoices(GUSEmuState *state, unsigned int playback_freq, unsigned int numsamples, short *bufferpos);
+void gus_mixvoices(GUSEmuState *state, unsigned int playback_freq, unsigned int numsamples, GUSsample *bufferpos);
 /* recommended range: 10 < numsamples < 100 */
 /* lower values may result in increased rounding error, higher values often cause audible timing delays */
 
diff --git a/hw/gusemu_mixer.c b/hw/gusemu_mixer.c
index b3b5aa5..6d8d9ce 100644
--- a/hw/gusemu_mixer.c
+++ b/hw/gusemu_mixer.c
@@ -33,7 +33,7 @@
 
 /* samples are always 16bit stereo (4 bytes each, first right then left interleaved) */
 void gus_mixvoices(GUSEmuState * state, unsigned int playback_freq, unsigned int numsamples,
-                   short *bufferpos)
+                   GUSsample *bufferpos)
 {
     /* note that byte registers are stored in the upper half of each voice register! */
     GUSbyte        *gusptr;
@@ -170,8 +170,8 @@
                 }
 
                 /* mix samples into buffer */
                 *(bufferpos + 2 * sample)     += (short) ((sample1 * PanningPos) >> 4);        /* right */
                 *(bufferpos + 2 * sample + 1) += (short) ((sample1 * (15 - PanningPos)) >> 4); /* left */
             }
             /* write back voice and volume */
             GUSvoice(wVSRCurrVol)   = Volume32 / 32;
@@ -170,8 +170,8 @@
 
                 /* mix samples into buffer */
-                *(bufferpos + 2 * sample)     += (short) ((sample1 * PanningPos) >> 4);        /* right */
-                *(bufferpos + 2 * sample + 1) += (short) ((sample1 * (15 - PanningPos)) >> 4); /* left */
+                *(bufferpos + 2 * sample)     += (GUSsample) ((sample1 * PanningPos) >> 4);        /* right */
+                *(bufferpos + 2 * sample + 1) += (GUSsample) ((sample1 * (15 - PanningPos)) >> 4); /* left */
             }
             /* write back voice and volume */